@@ -709,7 +709,8 @@ def sing_req_by_server(id_client_req, cert_path, data_path, auto=False,
         if os.path.exists(config):
             os.unlink(config)
 
-        from create_cert import sign_client_certifacation_request
+        from create_cert import (sign_client_certifacation_request,
+                CreateCertError)
 
         try:
             sign_client_certifacation_request(
