@@ -1775,8 +1775,14 @@ class WsdlMeta(type):
                     _dv.Set('cl_help_set', "on", force=True)
                 if params and params.dispatch_usenew:
                     _dv.Set('cl_dispatch_conf', "usenew", force=True)
-                if params and params.conargs:
-                    _dv.Set('cl_console_args', params.conargs, force=True)
+                if params:
+                    if params.conargs:
+                        conargs = list(params.conargs)
+                    else:
+                        conargs = []
+                    if params.dispatch_usenew:
+                        conargs.append("--force")
+                    _dv.Set('cl_console_args', conargs, force=True)
             else:
                 _dv = dv
             # созданием группы переменных из datavars согласно параметрам groups
